#[non_exhaustive]pub struct ExecutedTransaction {
pub transaction: Option<Transaction>,
pub signatures: Option<UserSignatures>,
pub effects: Option<TransactionEffects>,
pub events: Option<TransactionEvents>,
pub checkpoint: Option<u64>,
pub timestamp: Option<Timestamp>,
pub input_objects: Option<Objects>,
pub output_objects: Option<Objects>,
}Expand description
A transaction that has been executed, along with its signatures, effects, events and objects.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.transaction: Option<Transaction>The transaction itself.
signatures: Option<UserSignatures>List of user signatures that are used to authorize the execution of this transaction.
effects: Option<TransactionEffects>The TransactionEffects for this transaction.
events: Option<TransactionEvents>The TransactionEvents for this transaction.
This field might be empty, even if it was explicitly requested, if the
transaction didn’t produce any events.
iota.types.TransactionEffects.events_digest is populated if the
transaction produced any events.
checkpoint: Option<u64>The sequence number for the checkpoint that includes this transaction.
timestamp: Option<Timestamp>The Unix timestamp of the checkpoint that includes this transaction.
input_objects: Option<Objects>Set of input objects used by this transaction.
output_objects: Option<Objects>Set of output objects produced by this transaction.
Implementations
Sourceimpl ExecutedTransaction
impl ExecutedTransaction
pub const TRANSACTION_FIELD: &'static MessageField
pub const SIGNATURES_FIELD: &'static MessageField
pub const EFFECTS_FIELD: &'static MessageField
pub const EVENTS_FIELD: &'static MessageField
pub const CHECKPOINT_FIELD: &'static MessageField
pub const TIMESTAMP_FIELD: &'static MessageField
pub const INPUT_OBJECTS_FIELD: &'static MessageField
pub const OUTPUT_OBJECTS_FIELD: &'static MessageField
Sourceimpl ExecutedTransaction
impl ExecutedTransaction
Sourcepub fn with_transaction<T: Into<Transaction>>(self, field: T) -> Self
pub fn with_transaction<T: Into<Transaction>>(self, field: T) -> Self
Sets transaction with the provided value.
Sourcepub fn with_signatures<T: Into<UserSignatures>>(self, field: T) -> Self
pub fn with_signatures<T: Into<UserSignatures>>(self, field: T) -> Self
Sets signatures with the provided value.
Sourcepub fn with_effects<T: Into<TransactionEffects>>(self, field: T) -> Self
pub fn with_effects<T: Into<TransactionEffects>>(self, field: T) -> Self
Sets effects with the provided value.
Sourcepub fn with_events<T: Into<TransactionEvents>>(self, field: T) -> Self
pub fn with_events<T: Into<TransactionEvents>>(self, field: T) -> Self
Sets events with the provided value.
Sourcepub fn with_checkpoint(self, field: u64) -> Self
pub fn with_checkpoint(self, field: u64) -> Self
Sets checkpoint with the provided value.
Sourcepub fn with_timestamp<T: Into<Timestamp>>(self, field: T) -> Self
pub fn with_timestamp<T: Into<Timestamp>>(self, field: T) -> Self
Sets timestamp with the provided value.
Sourcepub fn with_input_objects<T: Into<Objects>>(self, field: T) -> Self
pub fn with_input_objects<T: Into<Objects>>(self, field: T) -> Self
Sets input_objects with the provided value.
Sourcepub fn with_output_objects<T: Into<Objects>>(self, field: T) -> Self
pub fn with_output_objects<T: Into<Objects>>(self, field: T) -> Self
Sets output_objects with the provided value.
Sourceimpl ExecutedTransaction
impl ExecutedTransaction
Sourcepub fn checkpoint(&self) -> u64
pub fn checkpoint(&self) -> u64
Returns the value of checkpoint, or the default value if checkpoint is unset.
Sourceimpl ExecutedTransaction
impl ExecutedTransaction
Sourcepub fn transaction(&self) -> Result<&Transaction, TryFromProtoError>
pub fn transaction(&self) -> Result<&Transaction, TryFromProtoError>
Get the transaction.
Returns the proto Transaction which provides:
Transaction::digest()— the transaction digestTransaction::transaction()— the deserialized SDKTransaction
Read mask: "transaction" (see
EXECUTED_TRANSACTION_TRANSACTION). For checkpoint context use
"transactions.transaction".
Sourcepub fn signatures(&self) -> Result<&UserSignatures, TryFromProtoError>
pub fn signatures(&self) -> Result<&UserSignatures, TryFromProtoError>
Get the user signatures.
Read mask: "signatures" (see EXECUTED_TRANSACTION_SIGNATURES).
For checkpoint context use "transactions.signatures".
Sourcepub fn effects(&self) -> Result<&TransactionEffects, TryFromProtoError>
pub fn effects(&self) -> Result<&TransactionEffects, TryFromProtoError>
Get the transaction effects.
Returns the proto TransactionEffects which provides:
TransactionEffects::digest()— the effects digestTransactionEffects::effects()— the deserialized SDKTransactionEffects
Read mask: "effects" (see EXECUTED_TRANSACTION_EFFECTS).
For checkpoint context use "transactions.effects".
Sourcepub fn events(&self) -> Result<&TransactionEvents, TryFromProtoError>
pub fn events(&self) -> Result<&TransactionEvents, TryFromProtoError>
Get the transaction events.
Returns the proto TransactionEvents which provides:
TransactionEvents::digest()— the events digestTransactionEvents::events()— the deserialized SDKTransactionEvents
Read mask: "events" (see EXECUTED_TRANSACTION_EVENTS).
For checkpoint context use "transactions.events".
Sourcepub fn checkpoint_sequence_number(
&self,
) -> Result<CheckpointSequenceNumber, TryFromProtoError>
pub fn checkpoint_sequence_number( &self, ) -> Result<CheckpointSequenceNumber, TryFromProtoError>
Get checkpoint sequence number.
Read mask: "checkpoint" (see EXECUTED_TRANSACTION_CHECKPOINT).
For checkpoint context use "transactions.checkpoint".
Sourcepub fn timestamp_ms(&self) -> Result<CheckpointTimestamp, TryFromProtoError>
pub fn timestamp_ms(&self) -> Result<CheckpointTimestamp, TryFromProtoError>
Get timestamp in milliseconds.
Read mask: "timestamp" (see EXECUTED_TRANSACTION_TIMESTAMP).
For checkpoint context use "transactions.timestamp".
Sourcepub fn input_objects(&self) -> Result<&Objects, TryFromProtoError>
pub fn input_objects(&self) -> Result<&Objects, TryFromProtoError>
Get input objects.
Returns proto Objects containing the
transaction’s input objects. Call .object() on each to deserialize.
Read mask: "input_objects" (see
EXECUTED_TRANSACTION_INPUT_OBJECTS).
For checkpoint context use "transactions.input_objects".
Sourcepub fn output_objects(&self) -> Result<&Objects, TryFromProtoError>
pub fn output_objects(&self) -> Result<&Objects, TryFromProtoError>
Get output objects.
Returns proto Objects containing the
transaction’s output objects. Call .object() on each to deserialize.
Read mask: "output_objects" (see
EXECUTED_TRANSACTION_OUTPUT_OBJECTS).
For checkpoint context use "transactions.output_objects".